package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcHjAddress;

/**
 * 户主信息Mapper接口
 * 
 * @author hs
 * @date 2024-03-15
 */
public interface SzxcHjAddressMapper 
{
    /**
     * 查询户主信息
     * 
     * @param id 户主信息主键
     * @return 户主信息
     */
    public SzxcHjAddress selectSzxcHjAddressById(Long id);

    /**
     * 查询户主信息列表
     * 
     * @param szxcHjAddress 户主信息
     * @return 户主信息集合
     */
    public List<SzxcHjAddress> selectSzxcHjAddressList(SzxcHjAddress szxcHjAddress);

    /**
     * 新增户主信息
     * 
     * @param szxcHjAddress 户主信息
     * @return 结果
     */
    public int insertSzxcHjAddress(SzxcHjAddress szxcHjAddress);

    /**
     * 修改户主信息
     * 
     * @param szxcHjAddress 户主信息
     * @return 结果
     */
    public int updateSzxcHjAddress(SzxcHjAddress szxcHjAddress);

    /**
     * 删除户主信息
     * 
     * @param id 户主信息主键
     * @return 结果
     */
    public int deleteSzxcHjAddressById(Long id);

    /**
     * 批量删除户主信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcHjAddressByIds(Long[] ids);
}
